__empId = 0;
__errorMsg = null;
__genericErrorHandler = function(errMsg){
	__errorMsg = errMsg;
};

window.onerror = function(errorMsg, url, lineNum){
	if (typeof __genericErrorHandler === 'function')
		__genericErrorHandler(errorMsg,url,lineNum);
	else
    	alert("Error in " + url + " at line " + lineNum + " : " + errorMsg);
    
    return true;
}

$(document).ready(function(){

	setJavaPreferences("alertErrors", true);
	appPath = getApplicationPath();
	if (appPath)
	{
		var dbPath = executeStaticJava("ram.kulkarni.war.sql.demo.SQLDemoUtils", "getSavedDBPath", appPath, null);
		__genericErrorHandler = null;
		if (__errorMsg)
			alert("Error getting saved DB path : " + __errorMsg);
		else if (dbPath)
			createDB(dbPath);
	}

    $("#fileBtn").click(function(){
        var filePath = executeStaticJava("ram.kulkarni.war.sql.demo.SQLDemoUtils", "openFileDialog", "", true,null);
        if (filePath)
            createDB(filePath);

		if (appPath && filePath)
			executeStaticJava("ram.kulkarni.war.sql.demo.SQLDemoUtils", "saveDBPath", appPath,filePath,null);
    });
	
	$("#exitButton").click(function(){
		exitWebAppRunner();
	});
    
    $("#addEmpBtn").click(function(){
	    $("#firstNameTxt").val("");
    	$("#lastNameTxt").val("");
    	$("#addressTxt").val("");
		__empId = 0;
		showEmployeeDetailDlg();
	});
	
	$("#createDbBtn").click(function(){
        var filePath = executeStaticJava("ram.kulkarni.war.sql.demo.SQLDemoUtils", "openFileDialog", "", false,null);
        if (filePath)
            createDB(filePath);

		if (appPath && filePath)
			executeStaticJava("ram.kulkarni.war.sql.demo.SQLDemoUtils", "saveDBPath", appPath,filePath,null);
	});
});

//Create table Employee if does not exist. Then read all employees from the table
//and display in a table.
function createDB(filePath){
    var ret = createJava("ram.kulkarni.war.sql.demo.EmployeeDBManager", filePath, "empMgr");
    
    if (!ret) {
        alert("Failed to create EmployeeDBManager");
        return;
    }
    
	refreshEmployeeTable();
}

//Display employee details dialog box. Used for inserting
//new employee and modifying existing employee 
function showEmployeeDetailDlg(){
    $("#empDtlDiv").dialog({
        title: "Employee Details",
        closeOnEscape: true,
        buttons: {
            "OK": onOK,
            "Cancel": onCancel
        }
    });
}

//Callback for OK button in employee detail dialog box
function onOK(){

	if (__empId == 0) //this was add operation
		addEmployee()
	else 
		editEmployee()
	
    $("#empDtlDiv").dialog("close");
}

//Callback for Cancel button in employee detail dialog box
function onCancel(){
    $("#empDtlDiv").dialog("close");
}

//Add new employee to the database, by getting
//details from the fields in employee detail dialog box
function addEmployee()
{	
    var firstName = $("#firstNameTxt").val();
    var lastName = $("#lastNameTxt").val();
    var address = $("#addressTxt").val();
    if (firstName == '' && lastName == '' && address == '') 
        return;
    var ret = createJava("ram.kulkarni.war.sql.demo.EmployeeVO", "empVO");
    executeJava("empVO", "setFirstName", firstName, null);
    executeJava("empVO", "setLastName", lastName, null);
    executeJava("empVO", "setAddress", address, null);
    var id = executeJava("empMgr", "addEmployee", "$empVO", null);
    if (id > 0) 
        addEmployeeRow(id, firstName, lastName, address);
}

//Updates employee details in the database.
function editEmployee()
{	
    var firstName = $("#firstNameTxt").val();
    var lastName = $("#lastNameTxt").val();
    var address = $("#addressTxt").val();
    if (firstName == '' && lastName == '' && address == '') 
        return;
    var ret = createJava("ram.kulkarni.war.sql.demo.EmployeeVO", "empVO");
    executeJava("empVO", "setId", parseInt(__empId, 10), null);
    executeJava("empVO", "setFirstName", firstName, null);
    executeJava("empVO", "setLastName", lastName, null);
    executeJava("empVO", "setAddress", address, null);
	
    executeJava("empMgr", "updateEmployee", "$empVO", null);
	
	var rowId = "empRow"+__empId;
	var empCells = $("#" + rowId + " td");

	if (empCells.length >= 3)
	{
		//first cell is firstName
		$(empCells[0]).text(firstName);
		$(empCells[1]).text(lastName);
		$(empCells[2]).text(address);
	}
}

//Gets all employees and displays in a table
function refreshEmployeeTable()
{
    $("#empDetailsDiv").children().remove();
    
    $("#empDivHeader").show();
    
    $("#empDetailsDiv").append("<table width='100%' id='empTable'>" +
    "<tr><th  align='left'>First Name</th><th  align='left'>Last Name</th><th  align='left'>Address</th></tr></table>");
    
    listEmployees();
    
    $("#empDetailsDiv").show();
}

//Helper function to add employee to HTML table
function addEmployeeRow(id, firstName, lastName, address){
    var rowStr = "<tr id='empRow" + id + "'><td>" + firstName 
	+ "</td><td>" + lastName + "</td><td>" + address +
    "</td></tr>";
    
    var row = $(rowStr).appendTo("#empTable");
    var editCell = $("<td></td>").appendTo(row);
    
    var editLink = $("<a href=''>edit</a>").appendTo(editCell);
	
    $(editLink).data("id", id).click(function(event){
        var id = $(event.srcElement).data("id");
    	   
		var rowId = "empRow"+id;
		var empCells = $("#" + rowId + " td");
	
		if (empCells.length >= 3)
		{
		    $("#firstNameTxt").val($(empCells[0]).text());
	    	$("#lastNameTxt").val($(empCells[1]).text());
	    	$("#addressTxt").val($(empCells[2]).text());
			
			__empId = id;
			showEmployeeDetailDlg();
		}
		    
        event.stopPropagation();
        return false;
    });
	
    var deleteCell = $("<td></td>").appendTo(row);
	var deleteLink = $("<a href=''>delete</a>").appendTo(deleteCell);
    $(deleteLink).data("id", id).click(function(event){
        var id = $(event.srcElement).data("id");
    	
		var rowId = "empRow"+id;
		var empCells = $("#" + rowId + " td");
		
		var empName = null;
		if (empCells.length >= 3)
			empName = $(empCells[0]).text() + " " + $(empCells[1]).text();
			
		if (!empName)
			return;
		
		if (confirm("Delete " + empName + "?"))
		{
			try {
				executeJava("empMgr", "deleteEmployee", id, null);
				$("#" + rowId).remove();
			} catch (err)
			{
				alert("Error deleting employee : " + err);
			}
		}
		    
        event.stopPropagation();
        return false;
    });
	
}

//get employees from the table and add to the HTML table
function listEmployees(){
    var ret = executeJava("empMgr", "getEmployees", "empArray");
    if (!ret) 
        return;
    var len = getJavaProperty("empArray", "length", null);
    for (var i = 0; i < len; i++) {
        var emp = getJavaArrayAt("empArray", i, "empAtIndex");
        
        if (!emp) 
            continue;
        
        var id = executeJava("empAtIndex", "getId", null);
        var firstName = executeJava("empAtIndex", "getFirstName", null);
        var lastName = executeJava("empAtIndex", "getLastName", null);
        var address = executeJava("empAtIndex", "getAddress", null);
        
        addEmployeeRow(id, firstName, lastName, address);
    }
}

